@@ -1,26 +1,25 @@
 """Application cache config."""
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 from starlite import CacheConfig
 from starlite.config.cache import default_cache_key_builder
 
-from . import redis, settings
+from starlite_saqlalchemy import redis, settings
 
 if TYPE_CHECKING:
+    from typing import Any
+
     from starlite.connection import Request
 
 
-def cache_key_builder(request: "Request") -> str:
-    """App name prefixed cache key builder.
+def cache_key_builder(request: Request[Any, Any]) -> str:
+    """
+    Args:
+        request: Current request instance.
 
-    Parameters
-    ----------
-    request : Request
-        Current request instance.
-
-    Returns
-    -------
-    str
+    Returns:
         App slug prefixed cache key.
     """
     return f"{settings.app.slug}:{default_cache_key_builder(request)}"
